@@ -4,11 +4,17 @@ library("tidywikidatar")
 test_that("check if image returned when valid id given", {
   testthat::skip_if_offline()
 
+  test_id_df <- tw_get(
+    id = "Q2",
+    id_l = tw_test_items
+  )
+
   expect_true(
     object = {
       tw_get_image(
         id = "Q2",
-        cache = FALSE
+        cache = FALSE,
+        id_df = test_id_df
       ) %>%
         tidyr::drop_na() %>%
         nrow() %>%
@@ -22,7 +28,8 @@ test_that("check if image returned when valid id given", {
     object = {
       tw_get_image(
         id = "Q2",
-        cache = TRUE
+        cache = TRUE,
+        id_df = test_id_df
       ) %>%
         tidyr::drop_na() %>%
         nrow() %>%
@@ -34,6 +41,11 @@ test_that("check if image returned when valid id given", {
 test_that("check if image returned when invalid id given", {
   testthat::skip_if_offline()
 
+  test_id_df <- tw_get(
+    id = "Q2",
+    id_l = tw_test_items
+  )
+
 
   expect_true(
     object = {
@@ -44,14 +56,20 @@ test_that("check if image returned when invalid id given", {
 
   expect_true(
     object = {
-      tw_get_image_same_length(id = "non_qid_string") %>%
+      tw_get_image_same_length(
+        id = "non_qid_string",
+        id_df = test_id_df
+      ) %>%
         is.na()
     }
   )
 
   expect_equal(
     object = {
-      tw_get_image_same_length(id = c("non_qid_string", NA)) %>%
+      tw_get_image_same_length(
+        id = c("non_qid_string", NA),
+        id_df = test_id_df
+      ) %>%
         is.na() %>%
         sum()
     }, expected = 2
@@ -59,7 +77,10 @@ test_that("check if image returned when invalid id given", {
 
   expect_equal(
     object = {
-      tw_get_image_same_length(id = c("non_qid_string", "Q2", "non_qid_string", NA)) %>%
+      tw_get_image_same_length(
+        id = c("non_qid_string", "Q2", "non_qid_string", NA),
+        id_df = test_id_df
+      ) %>%
         is.na() %>%
         which()
     }, expected = c(1, 3, 4)
@@ -71,6 +92,10 @@ test_that("check if image metadata returned correctly with or without cache", {
   testthat::skip_if_offline()
   testthat::skip_on_cran() # to prevent error due to calls to Wikimedia Commons from CRAN server
 
+  test_id_df <- tw_get(
+    id = "Q2",
+    id_l = tw_test_items
+  )
 
   expect_equal(
     object = {
@@ -99,7 +124,8 @@ test_that("check if image metadata returned correctly with or without cache", {
       df <- tw_get_image_metadata(
         id = c("Q2", NA, "not_an_id", "Q5"),
         only_first = TRUE,
-        cache = TRUE
+        cache = TRUE,
+        id_df = test_id_df
       )
 
       list(
@@ -123,7 +149,8 @@ test_that("check if image metadata returned correctly with or without cache", {
       df <- tw_get_image_metadata(
         id = c("Q2", NA, "not_an_id", "Q5"),
         only_first = TRUE,
-        cache = FALSE
+        cache = FALSE,
+        id_df = test_id_df
       )
 
       list(
